@@ -11,6 +11,7 @@ def test_model_subclassing_abstract_base_classes():
         some_field: str
 
 
+@pytest.mark.skipif(sys.version_info < (3, 12), reason='error value different on older versions')
 def test_model_subclassing_abstract_base_classes_without_implementation_raises_exception():
     class Model(BaseModel, abc.ABC):
         some_field: str
@@ -41,16 +42,7 @@ def test_model_subclassing_abstract_base_classes_without_implementation_raises_e
 
     with pytest.raises(TypeError) as excinfo:
         Model(some_field='some_value')
-
-    if sys.version_info < (3, 12):
-        message = (
-            "Can't instantiate abstract class Model with abstract methods "
-            "my_abstract_classmethod, my_abstract_method, my_abstract_property, my_abstract_staticmethod"  # noqa: Q000
-        )
-    else:
-        message = (
-            "Can't instantiate abstract class Model without an implementation for abstract methods "
-            "'my_abstract_classmethod', 'my_abstract_method', 'my_abstract_property', 'my_abstract_staticmethod'"
-        )
-
-    assert str(excinfo.value) == message
+    assert str(excinfo.value) == (
+        "Can't instantiate abstract class Model without an implementation for abstract methods "
+        "'my_abstract_classmethod', 'my_abstract_method', 'my_abstract_property', 'my_abstract_staticmethod'"
+    )
