@@ -1,8 +1,10 @@
 import re
+from typing import Final
 
 import pytest
+from typing_extensions import NotRequired, Required
 
-from pydantic import BaseModel, PydanticUserError, ValidationError
+from pydantic import BaseModel, PydanticForbiddenQualifier, PydanticUserError, ValidationError
 from pydantic.version import version_short
 
 
@@ -17,6 +19,18 @@ def test_user_error_url():
     )
 
 
+def test_forbidden_qualifier() -> None:
+    with pytest.raises(PydanticForbiddenQualifier):
+
+        class Model1(BaseModel):
+            a: Required[int]
+
+    with pytest.raises(PydanticForbiddenQualifier):
+
+        class Model2(BaseModel):
+            b: Final[NotRequired[str]] = 'test'
+
+
 @pytest.mark.parametrize(
     'hide_input,input_str',
     ((False, 'type=greater_than, input_value=4, input_type=int'), (True, 'type=greater_than')),
