@@ -4,13 +4,13 @@ Tests for TypedDict
 
 import sys
 import typing
-from typing import Any, Dict, Generic, List, Optional, TypeVar
+from typing import Annotated, Any, Generic, Optional, TypeVar
 
 import pytest
 import typing_extensions
 from annotated_types import Lt
 from pydantic_core import core_schema
-from typing_extensions import Annotated, TypedDict
+from typing_extensions import NotRequired, ReadOnly, Required, TypedDict
 
 from pydantic import (
     BaseModel,
@@ -52,10 +52,7 @@ def fixture_typed_dict(TypedDictAll):
     if sys.version_info < (3, 12) and TypedDictAll.__module__ == 'typing':
         pytest.skip('typing.TypedDict does not support all pydantic features in Python < 3.12')
 
-    if hasattr(TestTypedDict, '__required_keys__'):
-        return TypedDictAll
-    else:
-        pytest.skip('TypedDict does not include __required_keys__')
+    return TypedDictAll
 
 
 @pytest.fixture(
@@ -113,15 +110,21 @@ def test_typeddict_total_false(TypedDict, req_no_req):
     class MyDict(TypedDict, total=False):
         foo: Required[str]
         bar: int
+        baz: 'Required[int]'
 
     class M(BaseModel):
         d: MyDict
 
-    assert M(d=dict(foo='baz', bar='8')).d == {'foo': 'baz', 'bar': 8}
-    assert M(d=dict(foo='baz')).d == {'foo': 'baz'}
-    with pytest.raises(ValidationError, match=r'd\.foo\s+Field required \[type=missing,'):
+    assert M(d={'foo': 'baz', 'bar': '8', 'baz': 1}).d == {'foo': 'baz', 'bar': 8, 'baz': 1}
+    assert M(d={'foo': 'baz', 'baz': 1}).d == {'foo': 'baz', 'baz': 1}
+
+    with pytest.raises(ValidationError) as exc_info:
         M(d={})
 
+    assert exc_info.value.error_count() == 2
+    assert exc_info.value.errors()[0]['type'] == 'missing'
+    assert exc_info.value.errors()[1]['type'] == 'missing'
+
 
 def test_typeddict(TypedDict):
     class TD(TypedDict):
@@ -381,6 +384,7 @@ def test_typeddict_not_required_schema(TypedDict, req_no_req):
     class DataTD(TypedDict, total=True):
         a: NotRequired[int]
         b: str
+        c: 'NotRequired[int]'
 
     class Model(BaseModel):
         t: DataTD
@@ -397,6 +401,7 @@ def test_typeddict_not_required_schema(TypedDict, req_no_req):
                 'properties': {
                     'a': {'title': 'A', 'type': 'integer'},
                     'b': {'title': 'B', 'type': 'string'},
+                    'c': {'title': 'C', 'type': 'integer'},
                 },
                 'required': ['b'],
             }
@@ -497,12 +502,6 @@ def test_typeddict_annotated(TypedDict, input_value, expected):
 
 
 def test_recursive_typeddict():
-    from typing import Optional
-
-    from typing_extensions import TypedDict
-
-    from pydantic import BaseModel
-
     class RecursiveTypedDict(TypedDict):
         foo: Optional['RecursiveTypedDict']
 
@@ -528,7 +527,7 @@ T = TypeVar('T')
 def test_generic_typeddict_in_concrete_model():
     T = TypeVar('T')
 
-    class GenericTypedDict(typing_extensions.TypedDict, Generic[T]):
+    class GenericTypedDict(TypedDict, Generic[T]):
         x: T
 
     class Model(BaseModel):
@@ -541,7 +540,7 @@ def test_generic_typeddict_in_concrete_model():
         {
             'input': 'a',
             'loc': ('y', 'x'),
-            'msg': 'Input should be a valid integer, unable to parse string as an ' 'integer',
+            'msg': 'Input should be a valid integer, unable to parse string as an integer',
             'type': 'int_parsing',
         }
     ]
@@ -550,7 +549,7 @@ def test_generic_typeddict_in_concrete_model():
 def test_generic_typeddict_in_generic_model():
     T = TypeVar('T')
 
-    class GenericTypedDict(typing_extensions.TypedDict, Generic[T]):
+    class GenericTypedDict(TypedDict, Generic[T]):
         x: T
 
     class Model(BaseModel, Generic[T]):
@@ -563,7 +562,7 @@ def test_generic_typeddict_in_generic_model():
         {
             'input': 'a',
             'loc': ('y', 'x'),
-            'msg': 'Input should be a valid integer, unable to parse string as an ' 'integer',
+            'msg': 'Input should be a valid integer, unable to parse string as an integer',
             'type': 'int_parsing',
         }
     ]
@@ -572,7 +571,7 @@ def test_generic_typeddict_in_generic_model():
 def test_recursive_generic_typeddict_in_module(create_module):
     @create_module
     def module():
-        from typing import Generic, List, Optional, TypeVar
+        from typing import Generic, Optional, TypeVar
 
         from typing_extensions import TypedDict
 
@@ -585,7 +584,7 @@ def test_recursive_generic_typeddict_in_module(create_module):
 
         class RecursiveGenTypedDict(TypedDict, Generic[T]):
             foo: Optional['RecursiveGenTypedDict[T]']
-            ls: List[T]
+            ls: list[T]
 
     int_data: module.RecursiveGenTypedDict[int] = {'foo': {'foo': None, 'ls': [1]}, 'ls': [1]}
     assert module.RecursiveGenTypedDictModel[int](rec=int_data).rec == int_data
@@ -597,13 +596,13 @@ def test_recursive_generic_typeddict_in_module(create_module):
         {
             'input': 'a',
             'loc': ('rec', 'foo', 'ls', 0),
-            'msg': 'Input should be a valid integer, unable to parse string as an ' 'integer',
+            'msg': 'Input should be a valid integer, unable to parse string as an integer',
             'type': 'int_parsing',
         },
         {
             'input': 'a',
             'loc': ('rec', 'ls', 0),
-            'msg': 'Input should be a valid integer, unable to parse string as an ' 'integer',
+            'msg': 'Input should be a valid integer, unable to parse string as an integer',
             'type': 'int_parsing',
         },
     ]
@@ -615,7 +614,7 @@ def test_recursive_generic_typeddict_in_function_1():
     # First ordering: typed dict first
     class RecursiveGenTypedDict(TypedDict, Generic[T]):
         foo: Optional['RecursiveGenTypedDict[T]']
-        ls: List[T]
+        ls: list[T]
 
     class RecursiveGenTypedDictModel(BaseModel, Generic[T]):
         rec: 'RecursiveGenTypedDict[T]'
@@ -633,13 +632,13 @@ def test_recursive_generic_typeddict_in_function_1():
         {
             'input': 'a',
             'loc': ('rec', 'foo', 'ls', 0),
-            'msg': 'Input should be a valid integer, unable to parse string as an ' 'integer',
+            'msg': 'Input should be a valid integer, unable to parse string as an integer',
             'type': 'int_parsing',
         },
         {
             'input': 'a',
             'loc': ('rec', 'ls', 0),
-            'msg': 'Input should be a valid integer, unable to parse string as an ' 'integer',
+            'msg': 'Input should be a valid integer, unable to parse string as an integer',
             'type': 'int_parsing',
         },
     ]
@@ -654,7 +653,7 @@ def test_recursive_generic_typeddict_in_function_2():
 
     class RecursiveGenTypedDict(TypedDict, Generic[T]):
         foo: Optional['RecursiveGenTypedDict[T]']
-        ls: List[T]
+        ls: list[T]
 
     int_data: RecursiveGenTypedDict[int] = {'foo': {'foo': None, 'ls': [1]}, 'ls': [1]}
     assert RecursiveGenTypedDictModel[int](rec=int_data).rec == int_data
@@ -666,13 +665,13 @@ def test_recursive_generic_typeddict_in_function_2():
         {
             'input': 'a',
             'loc': ('rec', 'foo', 'ls', 0),
-            'msg': 'Input should be a valid integer, unable to parse string as an ' 'integer',
+            'msg': 'Input should be a valid integer, unable to parse string as an integer',
             'type': 'int_parsing',
         },
         {
             'input': 'a',
             'loc': ('rec', 'ls', 0),
-            'msg': 'Input should be a valid integer, unable to parse string as an ' 'integer',
+            'msg': 'Input should be a valid integer, unable to parse string as an integer',
             'type': 'int_parsing',
         },
     ]
@@ -688,7 +687,7 @@ def test_recursive_generic_typeddict_in_function_3():
 
     class RecursiveGenTypedDict(TypedDict, Generic[T]):
         foo: Optional['RecursiveGenTypedDict[T]']
-        ls: List[T]
+        ls: list[T]
 
     int_data: RecursiveGenTypedDict[int] = {'foo': {'foo': None, 'ls': [1]}, 'ls': [1]}
     assert IntModel(rec=int_data).rec == int_data
@@ -700,13 +699,13 @@ def test_recursive_generic_typeddict_in_function_3():
         {
             'input': 'a',
             'loc': ('rec', 'foo', 'ls', 0),
-            'msg': 'Input should be a valid integer, unable to parse string as an ' 'integer',
+            'msg': 'Input should be a valid integer, unable to parse string as an integer',
             'type': 'int_parsing',
         },
         {
             'input': 'a',
             'loc': ('rec', 'ls', 0),
-            'msg': 'Input should be a valid integer, unable to parse string as an ' 'integer',
+            'msg': 'Input should be a valid integer, unable to parse string as an integer',
             'type': 'int_parsing',
         },
     ]
@@ -749,42 +748,42 @@ def test_typeddict_inheritance(TypedDict: Any) -> None:
 
 def test_typeddict_field_validator(TypedDict: Any) -> None:
     class Parent(TypedDict):
-        a: List[str]
+        a: list[str]
 
         @field_validator('a')
         @classmethod
-        def parent_val_before(cls, v: List[str]):
+        def parent_val_before(cls, v: list[str]):
             v.append('parent before')
             return v
 
         @field_validator('a')
         @classmethod
-        def val(cls, v: List[str]):
+        def val(cls, v: list[str]):
             v.append('parent')
             return v
 
         @field_validator('a')
         @classmethod
-        def parent_val_after(cls, v: List[str]):
+        def parent_val_after(cls, v: list[str]):
             v.append('parent after')
             return v
 
     class Child(Parent):
         @field_validator('a')
         @classmethod
-        def child_val_before(cls, v: List[str]):
+        def child_val_before(cls, v: list[str]):
             v.append('child before')
             return v
 
         @field_validator('a')
         @classmethod
-        def val(cls, v: List[str]):
+        def val(cls, v: list[str]):
             v.append('child')
             return v
 
         @field_validator('a')
         @classmethod
-        def child_val_after(cls, v: List[str]):
+        def child_val_after(cls, v: list[str]):
             v.append('child after')
             return v
 
@@ -808,7 +807,7 @@ def test_typeddict_model_validator(TypedDict) -> None:
 
         @model_validator(mode='before')
         @classmethod
-        def val_model_before(cls, value: Dict[str, Any]) -> Dict[str, Any]:
+        def val_model_before(cls, value: dict[str, Any]) -> dict[str, Any]:
             return dict(x=value['x'] + 1, y=value['y'] + 2)
 
         @model_validator(mode='after')
@@ -822,18 +821,18 @@ def test_typeddict_model_validator(TypedDict) -> None:
 
 def test_typeddict_field_serializer(TypedDict: Any) -> None:
     class Parent(TypedDict):
-        a: List[str]
+        a: list[str]
 
         @field_serializer('a')
         @classmethod
-        def ser(cls, v: List[str]):
+        def ser(cls, v: list[str]):
             v.append('parent')
             return v
 
     class Child(Parent):
         @field_serializer('a')
         @classmethod
-        def ser(cls, v: List[str]):
+        def ser(cls, v: list[str]):
             v.append('child')
             return v
 
@@ -850,7 +849,7 @@ def test_typeddict_model_serializer(TypedDict) -> None:
         y: float
 
         @model_serializer(mode='plain')
-        def ser_model(self) -> Dict[str, Any]:
+        def ser_model(self) -> dict[str, Any]:
             return {'x': self['x'] * 2, 'y': self['y'] * 3}
 
     ta = TypeAdapter(Model)
@@ -929,3 +928,16 @@ def test_config_pushdown_typed_dict() -> None:
         model_config = ConfigDict(arbitrary_types_allowed=True)
 
         td: TD
+
+
+def test_readonly_qualifier_warning() -> None:
+    class TD(TypedDict):
+        a: Required[ReadOnly[int]]
+        b: ReadOnly[NotRequired[str]]
+
+    with pytest.raises(UserWarning, match="Items 'a', 'b' on TypedDict class 'TD' are using the `ReadOnly` qualifier"):
+        ta = TypeAdapter(TD)
+
+        with pytest.raises(ValidationError):
+            # Ensure required is taken into account:
+            ta.validate_python({})
