@@ -1,19 +1,27 @@
 import contextlib
 import re
-import sys
 from collections import deque
 from dataclasses import dataclass
 from datetime import date, datetime
 from enum import Enum
 from functools import partial, partialmethod
 from itertools import product
-from typing import Any, Callable, Deque, Dict, FrozenSet, List, NamedTuple, Optional, Tuple, Union
+from os.path import normcase
+from typing import (
+    Annotated,
+    Any,
+    Callable,
+    Literal,
+    NamedTuple,
+    Optional,
+    Union,
+)
 from unittest.mock import MagicMock
 
 import pytest
 from dirty_equals import HasRepr, IsInstance
 from pydantic_core import core_schema
-from typing_extensions import Annotated, Literal, TypedDict
+from typing_extensions import TypedDict
 
 from pydantic import (
     BaseModel,
@@ -64,7 +72,6 @@ def test_annotated_validator_before() -> None:
     assert Model(x='1.0').x == 1.0
 
 
-@pytest.mark.xfail(sys.version_info >= (3, 9) and sys.implementation.name == 'pypy', reason='PyPy 3.9+ bug')
 def test_annotated_validator_builtin() -> None:
     """https://github.com/pydantic/pydantic/issues/6752"""
     TruncatedFloat = Annotated[float, BeforeValidator(int)]
@@ -124,13 +131,13 @@ def test_annotated_validator_wrap() -> None:
 def test_annotated_validator_nested() -> None:
     MyInt = Annotated[int, AfterValidator(lambda x: x if x != -1 else 0)]
 
-    def non_decreasing_list(data: List[int]) -> List[int]:
+    def non_decreasing_list(data: list[int]) -> list[int]:
         for prev, cur in zip(data, data[1:]):
             assert cur >= prev
         return data
 
     class Model(BaseModel):
-        x: Annotated[List[MyInt], AfterValidator(non_decreasing_list)]
+        x: Annotated[list[MyInt], AfterValidator(non_decreasing_list)]
 
     assert Model(x=[0, -1, 2]).x == [0, 0, 2]
 
@@ -254,7 +261,7 @@ def test_int_overflow_validation(value):
 
 def test_frozenset_validation():
     class Model(BaseModel):
-        a: FrozenSet[int]
+        a: frozenset[int]
 
     with pytest.raises(ValidationError) as exc_info:
         Model(a='snap')
@@ -270,7 +277,7 @@ def test_frozenset_validation():
 
 def test_deque_validation():
     class Model(BaseModel):
-        a: Deque[int]
+        a: deque[int]
 
     with pytest.raises(ValidationError) as exc_info:
         Model(a='snap')
@@ -305,17 +312,17 @@ def test_deque_validation():
 
 def test_validate_whole():
     class Model(BaseModel):
-        a: List[int]
+        a: list[int]
 
         @field_validator('a', mode='before')
         @classmethod
-        def check_a1(cls, v: List[Any]) -> List[Any]:
+        def check_a1(cls, v: list[Any]) -> list[Any]:
             v.append('123')
             return v
 
         @field_validator('a')
         @classmethod
-        def check_a2(cls, v: List[int]) -> List[Any]:
+        def check_a2(cls, v: list[int]) -> list[Any]:
             v.append(456)
             return v
 
@@ -326,7 +333,7 @@ def test_validate_pre_error():
     calls = []
 
     class Model(BaseModel):
-        a: List[int]
+        a: list[int]
 
         @field_validator('a', mode='before')
         @classmethod
@@ -710,7 +717,11 @@ def test_validate_not_always():
 @pytest.mark.parametrize(
     'decorator, pytest_warns',
     [
-        (validator, pytest.warns(PydanticDeprecatedSince20, match=V1_VALIDATOR_DEPRECATION_MATCH)),
+        pytest.param(
+            validator,
+            pytest.warns(PydanticDeprecatedSince20, match=V1_VALIDATOR_DEPRECATION_MATCH),
+            marks=pytest.mark.thread_unsafe(reason='`pytest.warns()` is thread unsafe'),
+        ),
         (field_validator, contextlib.nullcontext()),
     ],
 )
@@ -751,7 +762,11 @@ def test_wildcard_validators(decorator, pytest_warns):
 @pytest.mark.parametrize(
     'decorator, pytest_warns',
     [
-        (validator, pytest.warns(PydanticDeprecatedSince20, match=V1_VALIDATOR_DEPRECATION_MATCH)),
+        pytest.param(
+            validator,
+            pytest.warns(PydanticDeprecatedSince20, match=V1_VALIDATOR_DEPRECATION_MATCH),
+            marks=pytest.mark.thread_unsafe(reason='`pytest.warns()` is thread unsafe'),
+        ),
         (field_validator, contextlib.nullcontext()),
     ],
 )
@@ -978,42 +993,42 @@ def test_inheritance_replace():
     """
 
     class Parent(BaseModel):
-        a: List[str]
+        a: list[str]
 
         @field_validator('a')
         @classmethod
-        def parent_val_before(cls, v: List[str]):
+        def parent_val_before(cls, v: list[str]):
             v.append('parent before')
             return v
 
         @field_validator('a')
         @classmethod
-        def val(cls, v: List[str]):
+        def val(cls, v: list[str]):
             v.append('parent')
             return v
 
         @field_validator('a')
         @classmethod
-        def parent_val_after(cls, v: List[str]):
+        def parent_val_after(cls, v: list[str]):
             v.append('parent after')
             return v
 
     class Child(Parent):
         @field_validator('a')
         @classmethod
-        def child_val_before(cls, v: List[str]):
+        def child_val_before(cls, v: list[str]):
             v.append('child before')
             return v
 
         @field_validator('a')
         @classmethod
-        def val(cls, v: List[str]):
+        def val(cls, v: list[str]):
             v.append('child')
             return v
 
         @field_validator('a')
         @classmethod
-        def child_val_after(cls, v: List[str]):
+        def child_val_after(cls, v: list[str]):
             v.append('child after')
             return v
 
@@ -1031,36 +1046,36 @@ def test_inheritance_replace_root_validator():
     with pytest.warns(PydanticDeprecatedSince20):
 
         class Parent(BaseModel):
-            a: List[str]
+            a: list[str]
 
             @root_validator(skip_on_failure=True)
-            def parent_val_before(cls, values: Dict[str, Any]):
+            def parent_val_before(cls, values: dict[str, Any]):
                 values['a'].append('parent before')
                 return values
 
             @root_validator(skip_on_failure=True)
-            def val(cls, values: Dict[str, Any]):
+            def val(cls, values: dict[str, Any]):
                 values['a'].append('parent')
                 return values
 
             @root_validator(skip_on_failure=True)
-            def parent_val_after(cls, values: Dict[str, Any]):
+            def parent_val_after(cls, values: dict[str, Any]):
                 values['a'].append('parent after')
                 return values
 
         class Child(Parent):
             @root_validator(skip_on_failure=True)
-            def child_val_before(cls, values: Dict[str, Any]):
+            def child_val_before(cls, values: dict[str, Any]):
                 values['a'].append('child before')
                 return values
 
             @root_validator(skip_on_failure=True)
-            def val(cls, values: Dict[str, Any]):
+            def val(cls, values: dict[str, Any]):
                 values['a'].append('child')
                 return values
 
             @root_validator(skip_on_failure=True)
-            def child_val_after(cls, values: Dict[str, Any]):
+            def child_val_after(cls, values: dict[str, Any]):
                 values['a'].append('child after')
                 return values
 
@@ -1072,7 +1087,7 @@ def test_validation_each_item():
     with pytest.warns(PydanticDeprecatedSince20, match=V1_VALIDATOR_DEPRECATION_MATCH):
 
         class Model(BaseModel):
-            foobar: Dict[int, int]
+            foobar: dict[int, int]
 
             @validator('foobar', each_item=True)
             @classmethod
@@ -1093,15 +1108,14 @@ def test_validation_each_item_invalid_type():
 
                 @validator('foobar', each_item=True)
                 @classmethod
-                def check_foobar(cls, v: Any):
-                    ...
+                def check_foobar(cls, v: Any): ...
 
 
 def test_validation_each_item_nullable():
     with pytest.warns(PydanticDeprecatedSince20, match=V1_VALIDATOR_DEPRECATION_MATCH):
 
         class Model(BaseModel):
-            foobar: Optional[List[int]]
+            foobar: Optional[list[int]]
 
             @validator('foobar', each_item=True)
             @classmethod
@@ -1115,11 +1129,11 @@ def test_validation_each_item_one_sublevel():
     with pytest.warns(PydanticDeprecatedSince20, match=V1_VALIDATOR_DEPRECATION_MATCH):
 
         class Model(BaseModel):
-            foobar: List[Tuple[int, int]]
+            foobar: list[tuple[int, int]]
 
             @validator('foobar', each_item=True)
             @classmethod
-            def check_foobar(cls, v: Tuple[int, int]) -> Tuple[int, int]:
+            def check_foobar(cls, v: tuple[int, int]) -> tuple[int, int]:
                 v1, v2 = v
                 assert v1 == v2
                 return v
@@ -1129,7 +1143,7 @@ def test_validation_each_item_one_sublevel():
 
 def test_key_validation():
     class Model(BaseModel):
-        foobar: Dict[int, int]
+        foobar: dict[int, int]
 
         @field_validator('foobar')
         @classmethod
@@ -1324,7 +1338,7 @@ def test_pre_called_once():
     check_calls = 0
 
     class Model(BaseModel):
-        a: Tuple[int, int, int]
+        a: tuple[int, int, int]
 
         @field_validator('a', mode='before')
         @classmethod
@@ -1364,7 +1378,7 @@ def test_assert_raises_validation_error():
 
 
 def test_root_validator():
-    root_val_values: List[Dict[str, Any]] = []
+    root_val_values: list[dict[str, Any]] = []
 
     class Model(BaseModel):
         a: int = 1
@@ -1379,14 +1393,14 @@ def test_root_validator():
         with pytest.warns(PydanticDeprecatedSince20):
 
             @root_validator(skip_on_failure=True)
-            def example_root_validator(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+            def example_root_validator(cls, values: dict[str, Any]) -> dict[str, Any]:
                 root_val_values.append(values)
                 if 'snap' in values.get('b', ''):
                     raise ValueError('foobar')
                 return dict(values, b='changed')
 
             @root_validator(skip_on_failure=True)
-            def example_root_validator2(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+            def example_root_validator2(cls, values: dict[str, Any]) -> dict[str, Any]:
                 root_val_values.append(values)
                 if 'snap' in values.get('c', ''):
                     raise ValueError('foobar2')
@@ -1436,7 +1450,7 @@ def test_root_validator_subclass():
 
             @root_validator(skip_on_failure=True)
             @classmethod
-            def root_val(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+            def root_val(cls, values: dict[str, Any]) -> dict[str, Any]:
                 assert cls is values['expected']
                 return values
 
@@ -1448,14 +1462,14 @@ def test_root_validator_subclass():
 
             @root_validator(skip_on_failure=True)
             @classmethod
-            def root_val(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+            def root_val(cls, values: dict[str, Any]) -> dict[str, Any]:
                 assert cls is Child2
                 values['x'] = values['x'] * 2
                 return values
 
     class Child3(Parent):
         @classmethod
-        def root_val(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+        def root_val(cls, values: dict[str, Any]) -> dict[str, Any]:
             assert cls is Child3
             values['x'] = values['x'] * 3
             return values
@@ -1467,7 +1481,7 @@ def test_root_validator_subclass():
 
 
 def test_root_validator_pre():
-    root_val_values: List[Dict[str, Any]] = []
+    root_val_values: list[dict[str, Any]] = []
 
     class Model(BaseModel):
         a: int = 1
@@ -1481,7 +1495,7 @@ def test_root_validator_pre():
         with pytest.warns(PydanticDeprecatedSince20):
 
             @root_validator(pre=True)
-            def root_validator(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+            def root_validator(cls, values: dict[str, Any]) -> dict[str, Any]:
                 root_val_values.append(values)
                 if 'snap' in values.get('b', ''):
                     raise ValueError('foobar')
@@ -1514,7 +1528,7 @@ def test_root_validator_types():
         with pytest.warns(PydanticDeprecatedSince20):
 
             @root_validator(skip_on_failure=True)
-            def root_validator(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+            def root_validator(cls, values: dict[str, Any]) -> dict[str, Any]:
                 nonlocal root_val_values
                 root_val_values = cls, repr(values)
                 return values
@@ -1544,8 +1558,6 @@ def test_root_validator_returns_none_exception():
 
 
 def test_model_validator_returns_ignore():
-    # This is weird, and I don't understand entirely why it's happening, but it kind of makes sense
-
     class Model(BaseModel):
         a: int = 1
 
@@ -1553,7 +1565,8 @@ def test_model_validator_returns_ignore():
         def model_validator_return_none(self) -> None:
             return None
 
-    m = Model(a=2)
+    with pytest.warns(UserWarning, match='A custom validator is returning a value other than `self`'):
+        m = Model(a=2)
     assert m.model_dump() == {'a': 2}
 
 
@@ -1786,7 +1799,8 @@ def test_overridden_root_validators():
         x: str
 
         @model_validator(mode='before')
-        def pre_root(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+        @classmethod
+        def pre_root(cls, values: dict[str, Any]) -> dict[str, Any]:
             validate_stub('A', 'pre')
             return values
 
@@ -1797,7 +1811,8 @@ def test_overridden_root_validators():
 
     class B(A):
         @model_validator(mode='before')
-        def pre_root(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+        @classmethod
+        def pre_root(cls, values: dict[str, Any]) -> dict[str, Any]:
             validate_stub('B', 'pre')
             return values
 
@@ -1817,14 +1832,14 @@ def test_overridden_root_validators():
 
 def test_validating_assignment_pre_root_validator_fail():
     class Model(BaseModel):
-        current_value: float = Field(..., alias='current')
+        current_value: float = Field(alias='current')
         max_value: float
 
         model_config = ConfigDict(validate_assignment=True)
         with pytest.warns(PydanticDeprecatedSince20):
 
             @root_validator(pre=True)
-            def values_are_not_string(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+            def values_are_not_string(cls, values: dict[str, Any]) -> dict[str, Any]:
                 if any(isinstance(x, str) for x in values.values()):
                     raise ValueError('values cannot be a string')
                 return values
@@ -1845,13 +1860,14 @@ def test_validating_assignment_pre_root_validator_fail():
 
 def test_validating_assignment_model_validator_before_fail():
     class Model(BaseModel):
-        current_value: float = Field(..., alias='current')
+        current_value: float = Field(alias='current')
         max_value: float
 
         model_config = ConfigDict(validate_assignment=True)
 
         @model_validator(mode='before')
-        def values_are_not_string(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+        @classmethod
+        def values_are_not_string(cls, values: dict[str, Any]) -> dict[str, Any]:
             assert isinstance(values, dict)
             if any(isinstance(x, str) for x in values.values()):
                 raise ValueError('values cannot be a string')
@@ -1879,7 +1895,7 @@ def test_validating_assignment_model_validator_before_fail():
         {'pre': False},
     ],
 )
-def test_root_validator_skip_on_failure_invalid(kwargs: Dict[str, Any]):
+def test_root_validator_skip_on_failure_invalid(kwargs: dict[str, Any]):
     with pytest.raises(TypeError, match='MUST specify `skip_on_failure=True`'):
         with pytest.warns(
             PydanticDeprecatedSince20, match='Pydantic V1 style `@root_validator` validators are deprecated.'
@@ -1887,7 +1903,7 @@ def test_root_validator_skip_on_failure_invalid(kwargs: Dict[str, Any]):
 
             class Model(BaseModel):
                 @root_validator(**kwargs)
-                def root_val(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+                def root_val(cls, values: dict[str, Any]) -> dict[str, Any]:
                     return values
 
 
@@ -1900,14 +1916,14 @@ def test_root_validator_skip_on_failure_invalid(kwargs: Dict[str, Any]):
         {'pre': True},
     ],
 )
-def test_root_validator_skip_on_failure_valid(kwargs: Dict[str, Any]):
+def test_root_validator_skip_on_failure_valid(kwargs: dict[str, Any]):
     with pytest.warns(
         PydanticDeprecatedSince20, match='Pydantic V1 style `@root_validator` validators are deprecated.'
     ):
 
         class Model(BaseModel):
             @root_validator(**kwargs)
-            def root_val(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+            def root_val(cls, values: dict[str, Any]) -> dict[str, Any]:
                 return values
 
 
@@ -1948,7 +1964,7 @@ def test_v1_validator_deprecated():
 
             @validator('x')
             @classmethod
-            def check_x(cls, x: int, values: Dict[str, Any]) -> int:
+            def check_x(cls, x: int, values: dict[str, Any]) -> int:
                 assert x * 2 == values['y']
                 return x
 
@@ -1960,7 +1976,7 @@ def test_v1_validator_deprecated():
     # check that we got stacklevel correct
     # if this fails you need to edit the stacklevel
     # parameter to warnings.warn in _decorators.py
-    assert w.filename == __file__
+    assert normcase(w.filename) == normcase(__file__)
     source = _get_source_line(w.filename, w.lineno)
     assert "@validator('x')" in source
 
@@ -2059,8 +2075,7 @@ def test_v1_validator_signature_kwargs_not_allowed() -> None:
                 a: int
 
                 @validator('a')
-                def check_a(cls, value: Any, foo: Any) -> Any:
-                    ...
+                def check_a(cls, value: Any, foo: Any) -> Any: ...
 
 
 def test_v1_validator_signature_kwargs1() -> None:
@@ -2087,7 +2102,7 @@ def test_v1_validator_signature_kwargs2() -> None:
             b: int
 
             @validator('b')
-            def check_b(cls, value: Any, values: Dict[str, Any], **kwargs: Any) -> Any:
+            def check_b(cls, value: Any, values: dict[str, Any], **kwargs: Any) -> Any:
                 assert kwargs == {}
                 assert values == {'a': 1}
                 assert value == 2
@@ -2104,7 +2119,7 @@ def test_v1_validator_signature_with_values() -> None:
             b: int
 
             @validator('b')
-            def check_b(cls, value: Any, values: Dict[str, Any]) -> Any:
+            def check_b(cls, value: Any, values: dict[str, Any]) -> Any:
                 assert values == {'a': 1}
                 assert value == 2
                 return value + 1
@@ -2120,7 +2135,7 @@ def test_v1_validator_signature_with_values_kw_only() -> None:
             b: int
 
             @validator('b')
-            def check_b(cls, value: Any, *, values: Dict[str, Any]) -> Any:
+            def check_b(cls, value: Any, *, values: dict[str, Any]) -> Any:
                 assert values == {'a': 1}
                 assert value == 2
                 return value + 1
@@ -2137,8 +2152,7 @@ def test_v1_validator_signature_with_field() -> None:
                 b: int
 
                 @validator('b')
-                def check_b(cls, value: Any, field: Any) -> Any:
-                    ...
+                def check_b(cls, value: Any, field: Any) -> Any: ...
 
 
 def test_v1_validator_signature_with_config() -> None:
@@ -2150,8 +2164,7 @@ def test_v1_validator_signature_with_config() -> None:
                 b: int
 
                 @validator('b')
-                def check_b(cls, value: Any, config: Any) -> Any:
-                    ...
+                def check_b(cls, value: Any, config: Any) -> Any: ...
 
 
 def test_model_config_validate_default():
@@ -2201,7 +2214,7 @@ def partial_val_func2(
 
 def partial_values_val_func1(
     value: int,
-    values: Dict[str, Any],
+    values: dict[str, Any],
     *,
     allowed: int,
 ) -> int:
@@ -2213,7 +2226,7 @@ def partial_values_val_func1(
 def partial_values_val_func2(
     value: int,
     *,
-    values: Dict[str, Any],
+    values: dict[str, Any],
     allowed: int,
 ) -> int:
     assert isinstance(values, dict)
@@ -2258,7 +2271,7 @@ def partial_cls_val_func2(
 def partial_cls_values_val_func1(
     cls: Any,
     value: int,
-    values: Dict[str, Any],
+    values: dict[str, Any],
     *,
     allowed: int,
     expected_cls: Any,
@@ -2273,7 +2286,7 @@ def partial_cls_values_val_func2(
     cls: Any,
     value: int,
     *,
-    values: Dict[str, Any],
+    values: dict[str, Any],
     allowed: int,
     expected_cls: Any,
 ) -> int:
@@ -2551,6 +2564,9 @@ def test_validator_allow_reuse_different_field_4():
     assert Model(x=1, y=2).model_dump() == {'x': 2, 'y': 3}
 
 
+@pytest.mark.filterwarnings(
+    'ignore:Pydantic V1 style `@root_validator` validators are deprecated.*:pydantic.warnings.PydanticDeprecatedSince20'
+)
 def test_root_validator_allow_reuse_same_field():
     with pytest.warns(UserWarning, match='`root_val` overrides an existing Pydantic `@root_validator` decorator'):
 
@@ -2558,12 +2574,12 @@ def test_root_validator_allow_reuse_same_field():
             x: int
 
             @root_validator(skip_on_failure=True)
-            def root_val(cls, v: Dict[str, Any]) -> Dict[str, Any]:
+            def root_val(cls, v: dict[str, Any]) -> dict[str, Any]:
                 v['x'] += 1
                 return v
 
             @root_validator(skip_on_failure=True)
-            def root_val(cls, v: Dict[str, Any]) -> Dict[str, Any]:
+            def root_val(cls, v: dict[str, Any]) -> dict[str, Any]:
                 v['x'] += 2
                 return v
 
@@ -2577,7 +2593,7 @@ def test_root_validator_allow_reuse_inheritance():
             x: int
 
             @root_validator(skip_on_failure=True)
-            def root_val(cls, v: Dict[str, Any]) -> Dict[str, Any]:
+            def root_val(cls, v: dict[str, Any]) -> dict[str, Any]:
                 v['x'] += 1
                 return v
 
@@ -2585,7 +2601,7 @@ def test_root_validator_allow_reuse_inheritance():
 
         class Child(Parent):
             @root_validator(skip_on_failure=True)
-            def root_val(cls, v: Dict[str, Any]) -> Dict[str, Any]:
+            def root_val(cls, v: dict[str, Any]) -> dict[str, Any]:
                 assert v == {'x': 1}
                 v = super().root_val(v)
                 assert v == {'x': 2}
@@ -2683,7 +2699,7 @@ def test_custom_type_field_name_model():
 def test_custom_type_field_name_model_nested():
     class MyModel(BaseModel):
         x: int
-        tuple_nested: Tuple[int, Foobar]
+        tuple_nested: tuple[int, Foobar]
 
     m = MyModel(x='123', tuple_nested=(1, 2))
     # insert_assert(m.tuple_nested[1])
@@ -2746,7 +2762,7 @@ def test_after_validator_field_name():
 def test_before_validator_field_name():
     class MyModel(BaseModel):
         x: int
-        foobar: Annotated[Dict[Any, Any], BeforeValidator(foobar_validate)]
+        foobar: Annotated[dict[Any, Any], BeforeValidator(foobar_validate)]
 
     m = MyModel(x='123', foobar='1')
     # insert_assert(m.foobar)
@@ -2869,6 +2885,45 @@ def test_plain_validator_plain_serializer() -> None:
     assert isinstance(data['bar'], ser_type)
 
 
+def test_plain_validator_plain_serializer_single_ser_call() -> None:
+    """https://github.com/pydantic/pydantic/issues/10385"""
+
+    ser_count = 0
+
+    def ser(v):
+        nonlocal ser_count
+        ser_count += 1
+        return v
+
+    class Model(BaseModel):
+        foo: Annotated[bool, PlainSerializer(ser), PlainValidator(lambda v: v)]
+
+    model = Model(foo=True)
+    data = model.model_dump()
+
+    assert data == {'foo': True}
+    assert ser_count == 1
+
+
+@pytest.mark.xfail(reason='https://github.com/pydantic/pydantic/issues/10428')
+def test_plain_validator_with_filter_dict_schema() -> None:
+    class MyDict:
+        @classmethod
+        def __get_pydantic_core_schema__(cls, source, handler):
+            return core_schema.dict_schema(
+                keys_schema=handler.generate_schema(str),
+                values_schema=handler.generate_schema(int),
+                serialization=core_schema.filter_dict_schema(
+                    include={'a'},
+                ),
+            )
+
+    class Model(BaseModel):
+        f: Annotated[MyDict, PlainValidator(lambda v: v)]
+
+    assert Model(f={'a': 1, 'b': 1}).model_dump() == {'f': {'a': 1}}
+
+
 def test_plain_validator_with_unsupported_type() -> None:
     class UnsupportedClass:
         pass
@@ -2883,3 +2938,129 @@ def test_plain_validator_with_unsupported_type() -> None:
     model = type_adapter.validate_python('abcdefg')
     assert isinstance(model, UnsupportedClass)
     assert isinstance(type_adapter.dump_python(model), UnsupportedClass)
+
+
+def test_validator_with_default_values() -> None:
+    def validate_x(v: int, unrelated_arg: int = 1, other_unrelated_arg: int = 2) -> int:
+        assert v != -1
+        return v
+
+    class Model(BaseModel):
+        x: int
+
+        val_x = field_validator('x')(validate_x)
+
+    with pytest.raises(ValidationError):
+        Model(x=-1)
+
+
+def test_field_validator_input_type_invalid_mode() -> None:
+    with pytest.raises(
+        PydanticUserError, match=re.escape("`json_schema_input_type` can't be used when mode is set to 'after'")
+    ):
+
+        class Model(BaseModel):
+            a: int
+
+            @field_validator('a', mode='after', json_schema_input_type=Union[int, str])  # pyright: ignore
+            @classmethod
+            def validate_a(cls, value: Any) -> Any: ...
+
+
+def test_non_self_return_val_warns() -> None:
+    class Child(BaseModel):
+        name: str
+
+        @model_validator(mode='after')  # type: ignore
+        def validate_model(self) -> 'Child':
+            return Child.model_construct(name='different')
+
+    with pytest.warns(UserWarning, match='A custom validator is returning a value other than `self`'):
+        c = Child(name='name')
+        # confirmation of behavior: non-self return value is ignored
+        assert c.name == 'name'
+
+
+def test_wrap_val_called_once() -> None:
+    """See https://github.com/pydantic/pydantic/issues/11505 for context.
+
+    This is effectively confirming that prebuilt validators aren't used for wrap validators.
+    """
+
+    class MyModel(BaseModel):
+        inner_value: str
+
+        @model_validator(mode='wrap')
+        @classmethod
+        def my_wrap_validator(cls, data, validator):
+            data['inner_value'] = 'wrap_prefix:' + data['inner_value']
+            return validator(data)
+
+    class MyParentModel(BaseModel):
+        nested: MyModel
+
+        @field_validator('nested', mode='wrap')
+        @classmethod
+        def wrapped_field_serializer(cls, field_value, validator):
+            return validator(field_value)
+
+    my_model = MyParentModel.model_validate({'nested': {'inner_value': 'foo'}})
+    assert my_model.nested.inner_value == 'wrap_prefix:foo'
+
+
+def test_after_val_called_once() -> None:
+    """See https://github.com/pydantic/pydantic/issues/11505 for context.
+
+    This is effectively confirming that prebuilt validators aren't used for after validators.
+    """
+
+    class MyModel(BaseModel):
+        inner_value: str
+
+        @model_validator(mode='after')
+        def my_after_validator(self):
+            self.inner_value = 'after_prefix:' + self.inner_value
+            return self
+
+    class MyParentModel(BaseModel):
+        nested: MyModel
+
+        @field_validator('nested', mode='wrap')
+        @classmethod
+        def wrapped_field_serializer(cls, field_value, validator):
+            return validator(field_value)
+
+    my_model = MyParentModel.model_validate({'nested': {'inner_value': 'foo'}})
+    assert my_model.nested.inner_value == 'after_prefix:foo'
+
+
+def test_after_and_wrap_combo_called_once() -> None:
+    """See https://github.com/pydantic/pydantic/issues/11505 for context.
+
+    This is effectively confirming that prebuilt validators aren't used for combinations of wrap and after validators.
+    """
+
+    class MyModel(BaseModel):
+        inner_value: str
+
+        @model_validator(mode='wrap')
+        @classmethod
+        def my_wrap_validator(cls, data, validator):
+            data['inner_value'] = 'wrap_prefix:' + data['inner_value']
+            return validator(data)
+
+        @model_validator(mode='after')
+        def my_after_validator(self):
+            self.inner_value = 'after_prefix:' + self.inner_value
+            return self
+
+    class MyParentModel(BaseModel):
+        nested: MyModel
+
+        @field_validator('nested', mode='wrap')
+        @classmethod
+        def wrapped_field_serializer(cls, field_value, validator):
+            return validator(field_value)
+
+    my_model = MyParentModel.model_validate({'nested': {'inner_value': 'foo'}})
+    assert my_model.nested.inner_value == 'after_prefix:wrap_prefix:foo'
